aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xci/before_script.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/ci/before_script.sh b/ci/before_script.sh
index 6a07c6747e..a0e87adb9e 100755
--- a/ci/before_script.sh
+++ b/ci/before_script.sh
@@ -35,9 +35,9 @@ fi
# Compile dependencies.
build_deps
# Install luacov for Lua coverage.
if [[ "$USE_LUACOV" == 1 ]]; then
- "${DEPS_BUILD_DIR}/usr/bin/luarocks" install luacov
+ "${DEPS_BUILD_DIR}/usr/bin/luarocks" install cluacov
fi
rm -rf "${LOG_DIR}"
@@ -35,9 +35,9 @@ fi
# Compile dependencies.
build_deps
-# Install luacov for Lua coverage.
+# Install cluacov for Lua coverage.
if [[ "$USE_LUACOV" == 1 ]]; then